import { AsyncLocalStorage } from 'node:async_hooks';
export const requestContext = new AsyncLocalStorage();
const createAccessors = (key) => {
    return [
        () => {
            const storage = requestContext.getStore();
            if (!storage) {
                throw new Error('[DevCycle] Request context not initialized. Please contact DevCycle support.');
            }
            return storage[key];
        },
        (value) => {
            const storage = requestContext.getStore();
            if (!storage) {
                throw new Error('[DevCycle] Request context not initialized. Please contact DevCycle support.');
            }
            storage[key] = value;
        },
    ];
};
export const [getIdentity, setIdentity] = createAccessors('identity');
export const [getClient, setClient] = createAccessors('client');
const [_getSDKKey, _setSDKKey] = createAccessors('sdkKey');
export const getSDKKey = () => {
    const key = _getSDKKey();
    if (!key) {
        throw new Error('SDK Client Key must be set!');
    }
    return key;
};
export const setSDKKey = (key) => {
    if (!key) {
        throw new Error('Missing SDK key! Provide a valid SDK key to DevCycleServersideProvider');
    }
    // attempt to make sure server keys don't leak to the client!
    if ((key === null || key === void 0 ? void 0 : key.length) &&
        !key.startsWith('dvc_client') &&
        !key.startsWith('client')) {
        throw new Error('Must use a client SDK key. This key will be sent to the client!');
    }
    _setSDKKey(key);
};
const [_getInitializedPromise, _setInitializedPromise] = createAccessors('initializedPromise');
export const getInitializedPromise = _getInitializedPromise;
export const setInitializedPromise = (promise) => {
    if (_getInitializedPromise()) {
        return;
    }
    _setInitializedPromise(promise);
};
export const [getOptions, setOptions] = createAccessors('options');
export const asyncStorageError = () => {
    return new Error('AsyncLocalStorage is not working as expected. Please contact DevCycle support.');
};
//# sourceMappingURL=requestContext.js.map